==> haskell-parameterized-utils-2.1.9.0-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-parameterized-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parameterized-utils
version:              2.1.9.0
visibility:           public
id:                   parameterized-utils-2.1.9.0-NOe53oScMw2OEHXGzAMGv
key:                  parameterized-utils-2.1.9.0-NOe53oScMw2OEHXGzAMGv
license:              BSD-3-Clause
copyright:            ©2016-2022 Galois, Inc.
maintainer:           kquick@galois.com, rscott@galois.com
author:               Galois Inc.
stability:            stable
homepage:             https://github.com/GaloisInc/parameterized-utils
synopsis:
    Classes and data structures for working with data-kind indexed types

description:
    This package contains collection classes and type representations
    used for working with values that have a single parameter.  It'\''s
    intended for things like expression libraries where one wishes
    to leverage the Haskell type-checker to improve type-safety by encoding
    the object language type system into data kinds.

category:             Data Structures, Dependent Types
abi:                  6b2b1cabcae9a95afbf5ffb508bf21ef
exposed:              True
exposed-modules:
    Data.Parameterized Data.Parameterized.All Data.Parameterized.Axiom
    Data.Parameterized.BoolRepr Data.Parameterized.Classes
    Data.Parameterized.ClassesC Data.Parameterized.Compose
    Data.Parameterized.Context Data.Parameterized.Context.Safe
    Data.Parameterized.Context.Unsafe Data.Parameterized.Ctx
    Data.Parameterized.Ctx.Proofs Data.Parameterized.DataKind
    Data.Parameterized.DecidableEq Data.Parameterized.Fin
    Data.Parameterized.FinMap Data.Parameterized.FinMap.Safe
    Data.Parameterized.FinMap.Unsafe Data.Parameterized.HashTable
    Data.Parameterized.List Data.Parameterized.Map
    Data.Parameterized.NatRepr Data.Parameterized.Nonce
    Data.Parameterized.Nonce.Transformers
    Data.Parameterized.Nonce.Unsafe Data.Parameterized.Pair
    Data.Parameterized.Peano Data.Parameterized.Some
    Data.Parameterized.SymbolRepr Data.Parameterized.TH.GADT
    Data.Parameterized.TraversableF Data.Parameterized.TraversableFC
    Data.Parameterized.TraversableFC.WithIndex
    Data.Parameterized.Utils.BinTree Data.Parameterized.Utils.Endian
    Data.Parameterized.Vector Data.Parameterized.WithRepr

hidden-modules:       Data.Parameterized.NatRepr.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/parameterized-utils-2.1.9.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/parameterized-utils-2.1.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parameterized-utils
hs-libraries:         HSparameterized-utils-2.1.9.0-NOe53oScMw2OEHXGzAMGv
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW
    constraints-0.13.4-7zdNhBEZCHL204LP1Lqk4K containers-0.6.5.1
    deepseq-1.4.6.1 ghc-prim-0.8.0
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    hashtables-1.3.1-19pwafFiCaCEjS0N0RfZKT
    indexed-traversable-0.1.3-FGAp4VsezN7HyqjQRvrfWc
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0 mtl-2.2.2
    profunctors-5.6.2-FWe4PQU8eE3GeDqm3R4ckm template-haskell-2.18.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-parameterized-utils/html/parameterized-utils.haddock

haddock-html:         /usr/share/doc/haskell-parameterized-utils/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parameterized-utils-2.1.10.0-25.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-parameterized-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parameterized-utils
version:              2.1.10.0
visibility:           public
id:                   parameterized-utils-2.1.10.0-9DchLobtecYATWN13d0xst
key:                  parameterized-utils-2.1.10.0-9DchLobtecYATWN13d0xst
license:              BSD-3-Clause
copyright:            ©2016-2022 Galois, Inc.
maintainer:           kquick@galois.com, rscott@galois.com
author:               Galois Inc.
stability:            stable
homepage:             https://github.com/GaloisInc/parameterized-utils
synopsis:
    Classes and data structures for working with data-kind indexed types

description:
    This package contains collection classes and type representations
    used for working with values that have a single parameter.  It'\''s
    intended for things like expression libraries where one wishes
    to leverage the Haskell type-checker to improve type-safety by encoding
    the object language type system into data kinds.

category:             Data Structures, Dependent Types
abi:                  2cd684a4f5578aa4b71c1aefd33ff0fa
exposed:              True
exposed-modules:
    Data.Parameterized Data.Parameterized.All Data.Parameterized.Axiom
    Data.Parameterized.BoolRepr Data.Parameterized.Classes
    Data.Parameterized.ClassesC Data.Parameterized.Compose
    Data.Parameterized.Context Data.Parameterized.Context.Safe
    Data.Parameterized.Context.Unsafe Data.Parameterized.Ctx
    Data.Parameterized.Ctx.Proofs Data.Parameterized.DataKind
    Data.Parameterized.DecidableEq Data.Parameterized.Fin
    Data.Parameterized.FinMap Data.Parameterized.FinMap.Safe
    Data.Parameterized.FinMap.Unsafe Data.Parameterized.HashTable
    Data.Parameterized.List Data.Parameterized.Map
    Data.Parameterized.NatRepr Data.Parameterized.Nonce
    Data.Parameterized.Nonce.Transformers
    Data.Parameterized.Nonce.Unsafe Data.Parameterized.Pair
    Data.Parameterized.Peano Data.Parameterized.Some
    Data.Parameterized.SymbolRepr Data.Parameterized.TH.GADT
    Data.Parameterized.TraversableF Data.Parameterized.TraversableFC
    Data.Parameterized.TraversableFC.WithIndex
    Data.Parameterized.Utils.BinTree Data.Parameterized.Utils.Endian
    Data.Parameterized.Vector Data.Parameterized.WithRepr

hidden-modules:       Data.Parameterized.NatRepr.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parameterized-utils
hs-libraries:         HSparameterized-utils-2.1.10.0-9DchLobtecYATWN13d0xst
depends:
    base-4.17.2.1 base-orphans-0.9.1-H5ZKrdj0NFhGxOpdRcZ2du
    constraints-0.13.4-GRCASd6TdIJDk065yZIoKs containers-0.6.7
    deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    hashtables-1.3.1-2lIi4A9XzcGEFFrCjsaDCt
    indexed-traversable-0.1.4-KBBDB9eVvy75srrGe861vR
    lens-5.2.3-7k2QwsHyLcVK6NgbwpIzej mtl-2.2.2
    profunctors-5.6.2-2HJkXKlrQqeIGAKueBx4y0 template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:
    /usr/share/doc/haskell-parameterized-utils/html/parameterized-utils.haddock

haddock-html:         /usr/share/doc/haskell-parameterized-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
